@@ -149,10 +149,10 @@ impl Lower32 {
             .get_mut(..s.len())?
             .copy_from_slice(s.as_bytes());
 
-        self.0[0] |= 0x20202020_20202020_u64;
-        self.0[1] |= 0x20202020_20202020_u64;
-        self.0[2] |= 0x20202020_20202020_u64;
-        self.0[3] |= 0x20202020_20202020_u64;
+        self.0[0] |= 0x2020_2020_2020_2020_u64;
+        self.0[1] |= 0x2020_2020_2020_2020_u64;
+        self.0[2] |= 0x2020_2020_2020_2020_u64;
+        self.0[3] |= 0x2020_2020_2020_2020_u64;
 
         std::str::from_utf8(self.0.as_byte_slice())
             .ok()?
